@@ -8,9 +8,9 @@ use Log::ger;
 use App::orgadb::Common;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-10-09'; # DATE
+our $DATE = '2022-10-15'; # DATE
 our $DIST = 'App-orgadb'; # DIST
-our $VERSION = '0.010'; # VERSION
+our $VERSION = '0.011'; # VERSION
 
 our %SPEC;
 
@@ -40,14 +40,16 @@ sub _select_single {
     my $tree_filenames = $args{_tree_filenames};
 
     my $res = [200, "OK", ""];
+    my @outputted_field_values;
 
     my @parsed_default_formatter_rules;
 
-    my ($formatter, @filter_names);
+    my $formatter;
   SET_FORMATTERS:
     {
         last if $args{no_formatters};
         last unless $args{formatters} && @{ $args{formatters} };
+        my @filter_names;
         for my $f (@{ $args{formatters} }) {
             if ($f =~ /\A\[/) {
                 require JSON::PP;
@@ -234,17 +236,23 @@ sub _select_single {
                             $re_field,
                             $field->bullet . ' ' . $field_name0,
                         ) . " ::";
-                        $res->[2] .= $field_name;
+                        unless ($args{clipboard} && $args{clipboard} eq 'only') {
+                            $res->[2] .= $field_name;
+                        }
                     }
 
-                    my ($default_formatter);
+                    my $default_formatter;
                   SET_DEFAULT_FORMATTERS:
                     {
                         last if $args{no_formatters};
                         last if $formatter;
                         last unless $args{default_formatter_rules} && @{ $args{default_formatter_rules} };
+
+                        my $default_formatters = [];
                         unless (@parsed_default_formatter_rules) {
+                            my $i = -1;
                             for my $r0 (@{ $args{default_formatter_rules} }) {
+                                $i++;
                                 my $r;
                                 if (!ref($r0) && $r0 =~ /\A\{/) {
                                     require JSON::PP;
@@ -260,7 +268,7 @@ sub _select_single {
                                 }
 
                                 if ($r->{formatters} && @{ $r->{formatters} }) {
-                                    my @filter_names2;
+                                    my @filter_names;
                                     for my $f (@{ $r->{formatters} }) {
                                         if ($f =~ /\A\[/) {
                                             require JSON::PP;
@@ -276,13 +284,15 @@ sub _select_single {
                                                 $f =~ s!/!::!g;
                                             }
                                         }
-                                        push @filter_names2, $f;
+                                        push @filter_names, $f;
                                     }
                                     require Data::Sah::Filter;
                                     $r->{formatter} = Data::Sah::Filter::gen_filter(
-                                        filter_names => \@filter_names2,
+                                        filter_names => \@filter_names,
                                         return_type => 'str_errmsg+val',
                                     );
+                                } else {
+                                    die "Default formatting rules [$i] does not have non-empty formatters: %s", $r;
                                 }
                                 push @parsed_default_formatter_rules, $r;
                             }
@@ -302,9 +312,31 @@ sub _select_single {
                                     next RULE;
                                 };
                             }
-                            log_trace "Using formatters from default_formatter_rules[%d] (%s) for field name %s", $i, $r->{formatters}, $field_name0;
-                            $default_formatter = $r->{formatter};
-                            last RULE;
+                            if (defined $r->{hide_field_name}) {
+                                if ($args{hide_field_name} xor $r->{hide_field_name}) {
+                                    $matches = 0;
+                                    log_trace "Skipping default_formatter_rules[%d]: hide_field_name condition (%s) doesn't match actual hide_field_name option (%s)", $i, ($r->{hide_field_name} ? 'true':'false'), ($args{hide_field_name} ? 'true':'false');
+                                    next RULE;
+                                }
+                            }
+                            log_trace "Adding formatters from default_formatter_rules[%d] (%s) for field name %s", $i, $r->{formatters}, $field_name0;
+                            push @$default_formatters, $r->{formatter};
+                        }
+                        # combine default formatters
+                        last unless @$default_formatters;
+                        if (@$default_formatters > 1) {
+                            $default_formatter = sub {
+                                my $val = shift;
+                                my $res;
+                                for my $i (0 .. $#{$default_formatters}) {
+                                    $res = $default_formatters->[$i]->($val);
+                                    return $res if $res->[0];
+                                    $val = $res->[1];
+                                }
+                                $res;
+                            };
+                        } else {
+                            $default_formatter = $default_formatters->[0];
                         }
                     } # SET_DEFAULT_FORMATTERS
 
@@ -313,18 +345,33 @@ sub _select_single {
                     if ($formatter || $default_formatter) {
                         my ($ferr, $fres) = @{ ($formatter || $default_formatter)->($field_value) };
                         if ($ferr) {
-                            log_warn "Formatting error: field value=%s, formatters=%s, errmsg=%s", $field_value, \@filter_names, $ferr;
+                            log_warn "Formatting error: field value=%s, errmsg=%s", $field_value, $ferr;
                             $field_value = "$field_value # CAN'T FORMAT: $ferr";
                         } else {
                             $field_value = $fres;
                         }
                     }
-                    $res->[2] .= ($args{hide_field_name} ? "" : $prefix) . $field_value . $suffix;
+                    unless ($args{clipboard} && $args{clipboard} eq 'only') {
+                        $res->[2] .= ($args{hide_field_name} ? "" : $prefix) . $field_value . $suffix;
+                    }
+                    push @outputted_field_values, $field_value;
                 }
             }
         }
     }
 
+  COPY_TO_CLIPBOARD: {
+        last unless $args{clipboard};
+        last unless @outputted_field_values;
+        require Clipboard::Any;
+        log_info "Copying matching field values to clipboard ...";
+        my $res = Clipboard::Any::add_clipboard_content(content => join "\n", @outputted_field_values);
+        if ($res->[0] != 200) {
+            log_warn "Cannot copy to clipboard: $res->[0] - $res->[1]";
+            last;
+        }
+    }
+
     $res;
 }
 
@@ -431,10 +478,20 @@ App::orgadb - An opinionated Org addressbook toolset
 
 =head1 VERSION
 
-This document describes version 0.010 of App::orgadb (from Perl distribution App-orgadb), released on 2022-10-09.
+This document describes version 0.011 of App::orgadb (from Perl distribution App-orgadb), released on 2022-10-15.
 
 =head1 SYNOPSIS
 
+=head1 DESCRIPTION
+
+This distribution includes the following CLI's:
+
+=over
+
+=item * L<orgadb-sel>
+
+=back
+
 =head1 FUNCTIONS
 
 
@@ -456,6 +513,16 @@ Arguments ('*' denotes required arguments):
 
 Find entry by string or regex search against the category title.
 
+=item * B<clipboard> => I<str>
+
+Whether to copy matching field values to clipboard.
+
+If set to C<tee>, then will display matching fields to terminal as well as copy
+matching field values to clipboard.
+
+If set to C<only>, then will not display matching fields to terminal and will
+only copy matching field values to clipboard.
+
 =item * B<color> => I<str> (default: "auto")
 
 Whether to use color.
@@ -466,13 +533,56 @@ Whether to use color.
 
 Return just the number of matching entries instead of showing them.
 
-=item * B<default_formatter_rules> => I<array[any]>
+=item * B<default_formatter_rules> => I<array[hash]>
 
-Specify conditional default formatters. This is for convenience and best
-specified in the configuration as opposed to on the command-line option.
-An example:
+Specify conditional default formatters, as an array of hashes. Each element is a
+rule that is specified as a hash containing condition keys and formatters keys.
+If all conditions are met then the formatters will be applied. The rules will be
+tested when each field is about to be outputted. Multiple rules can match and
+the matching rules' formatters are all applied in succession.
 
- default_formatter_rules={"field_name_matches":"/phone|wa|whatsapp/i","formatters":[ ["Phone::format_phone_idn"] ]}
+Note that this option will be overridden by the C<--formatter> or the
+C<--no-formatters> (C<-F>) option.
+
+Default formatters are best specified in the configuration as opposed to on the
+command-line option. An example (the lines below are writen in configuration
+file in IOD syntax, as rows of JSON hashes):
+
+ ; by default remove all comments in field values when 'hide_field_name'
+ ; option is set (which usually means we want to copy paste things)
+ default_formatter_rules={"hide_field_name":true, "formatters":[ ["Str::remove_comment"] ]}
+ 
+ ; by default normalize phone numbers using Phone::format_phone_idn_nospace
+ ; when 'hide_field_name' option is set (which usually means we want to copy
+ ; paste things). e.g. '0812-1234-5678' becomes '+6281212345678'.
+ default_formatter_rules={"field_name_matches":"/phone|wa|whatsapp/i", "hide_field_name":true, "formatters":[ ["Phone::format_phone_idn_nospace"] ]}
+ 
+ ; but if 'hide_field_name' field is not set, normalize phone numbers using
+ ; Phone::format_phone_idn which is more easier to see (e.g. '+62 812 1234
+ ; 5678').
+ default_formatter_rules={"field_name_matches":"/phone|wa|whatsapp/i", "hide_field_name":false, "formatters":[ ["Phone::format_phone_idn_nospace"] ]}
+
+Condition keys:
+
+=over
+
+=item * C<field_name_matches> (value: str/re): Check if field name matches a regex pattern.
+
+=item * C<hide_field_name> (value: bool): Check if C<--hide-field-name> (C<-N>) option is
+set (true) or unset (false).
+
+=back
+
+Formatter keys:
+
+=over
+
+=item * C<formatters>: an array of formatters, to be applied. Each formatter is a name
+of perl Sah filter rule, or a two-element array of perl Sah filter rule name
+followed by hash containing arguments. See C<--formatter> for more detais on
+specifying formatter.
+
+=back
 
 =item * B<detail> => I<bool>
 
@@ -523,8 +633,8 @@ If formatter name begins with C<[> character, it will be parsed as JSON. Example
 
  ['Str::remove_comment', {'style':'cpp'}]
 
-Overrides C<--default_formatter_rule> but overridden by the C<--no-formatters>
-(C<--raw-field-values>, C<-F>) option.
+Note that this option verrides C<--default-formatter-rules> but overridden by the
+C<--no-formatters> (C<--raw-field-values>, C<-F>) option.
 
 =item * B<hide_category> => I<true>
 
@@ -542,6 +652,9 @@ Do not show field names, just show field values.
 
 Do not apply any formatters to field value (overrides --formatter option).
 
+Note that this option has higher precedence than C<--default-formatter-rules> or
+the C<--formatter> option.
+
 =item * B<num_entries> => I<uint>
 
 Specify maximum number of entries to return (0 means unlimited).
