@@ -6,9 +6,9 @@ use warnings;
 use Log::ger;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-10-09'; # DATE
+our $DATE = '2022-10-15'; # DATE
 our $DIST = 'App-orgadb'; # DIST
-our $VERSION = '0.010'; # VERSION
+our $VERSION = '0.011'; # VERSION
 
 use App::orgadb::Common;
 
@@ -127,7 +127,7 @@ App::orgadb::Select::Shell::Commands - orgadb-sel shell commands
 
 =head1 VERSION
 
-This document describes version 0.010 of App::orgadb::Select::Shell::Commands (from Perl distribution App-orgadb), released on 2022-10-09.
+This document describes version 0.011 of App::orgadb::Select::Shell::Commands (from Perl distribution App-orgadb), released on 2022-10-15.
 
 =for Pod::Coverage .+
 
@@ -194,17 +194,70 @@ Arguments ('*' denotes required arguments):
 
 Find entry by string or regex search against the category title.
 
+=item * B<clipboard> => I<str>
+
+Whether to copy matching field values to clipboard.
+
+If set to C<tee>, then will display matching fields to terminal as well as copy
+matching field values to clipboard.
+
+If set to C<only>, then will not display matching fields to terminal and will
+only copy matching field values to clipboard.
+
 =item * B<count> => I<true>
 
 Return just the number of matching entries instead of showing them.
 
-=item * B<default_formatter_rules> => I<array[any]>
+=item * B<default_formatter_rules> => I<array[hash]>
 
-Specify conditional default formatters. This is for convenience and best
-specified in the configuration as opposed to on the command-line option.
-An example:
+Specify conditional default formatters, as an array of hashes. Each element is a
+rule that is specified as a hash containing condition keys and formatters keys.
+If all conditions are met then the formatters will be applied. The rules will be
+tested when each field is about to be outputted. Multiple rules can match and
+the matching rules' formatters are all applied in succession.
 
- default_formatter_rules={"field_name_matches":"/phone|wa|whatsapp/i","formatters":[ ["Phone::format_phone_idn"] ]}
+Note that this option will be overridden by the C<--formatter> or the
+C<--no-formatters> (C<-F>) option.
+
+Default formatters are best specified in the configuration as opposed to on the
+command-line option. An example (the lines below are writen in configuration
+file in IOD syntax, as rows of JSON hashes):
+
+ ; by default remove all comments in field values when 'hide_field_name'
+ ; option is set (which usually means we want to copy paste things)
+ default_formatter_rules={"hide_field_name":true, "formatters":[ ["Str::remove_comment"] ]}
+ 
+ ; by default normalize phone numbers using Phone::format_phone_idn_nospace
+ ; when 'hide_field_name' option is set (which usually means we want to copy
+ ; paste things). e.g. '0812-1234-5678' becomes '+6281212345678'.
+ default_formatter_rules={"field_name_matches":"/phone|wa|whatsapp/i", "hide_field_name":true, "formatters":[ ["Phone::format_phone_idn_nospace"] ]}
+ 
+ ; but if 'hide_field_name' field is not set, normalize phone numbers using
+ ; Phone::format_phone_idn which is more easier to see (e.g. '+62 812 1234
+ ; 5678').
+ default_formatter_rules={"field_name_matches":"/phone|wa|whatsapp/i", "hide_field_name":false, "formatters":[ ["Phone::format_phone_idn_nospace"] ]}
+
+Condition keys:
+
+=over
+
+=item * C<field_name_matches> (value: str/re): Check if field name matches a regex pattern.
+
+=item * C<hide_field_name> (value: bool): Check if C<--hide-field-name> (C<-N>) option is
+set (true) or unset (false).
+
+=back
+
+Formatter keys:
+
+=over
+
+=item * C<formatters>: an array of formatters, to be applied. Each formatter is a name
+of perl Sah filter rule, or a two-element array of perl Sah filter rule name
+followed by hash containing arguments. See C<--formatter> for more detais on
+specifying formatter.
+
+=back
 
 =item * B<detail> => I<bool>
 
@@ -251,8 +304,8 @@ If formatter name begins with C<[> character, it will be parsed as JSON. Example
 
  ['Str::remove_comment', {'style':'cpp'}]
 
-Overrides C<--default_formatter_rule> but overridden by the C<--no-formatters>
-(C<--raw-field-values>, C<-F>) option.
+Note that this option verrides C<--default-formatter-rules> but overridden by the
+C<--no-formatters> (C<--raw-field-values>, C<-F>) option.
 
 =item * B<hide_category> => I<true>
 
@@ -270,6 +323,9 @@ Do not show field names, just show field values.
 
 Do not apply any formatters to field value (overrides --formatter option).
 
+Note that this option has higher precedence than C<--default-formatter-rules> or
+the C<--formatter> option.
+
 =item * B<num_entries> => I<uint>
 
 Specify maximum number of entries to return (0 means unlimited).
